tlslite.messages.RecordHeader3

Package tlslite :: Module messages :: Class RecordHeader3 |
[hide private]
[frames] | no frames]

# Class RecordHeader3

source code

    object --+
             |
            RecordHeader3

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
create(self, version, type, length) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)